skzeros
=======

.. currentmodule:: skzeros

Main Zeros Finding Function
=============
.. autosummary::
   :toctree: generated/

   find_zeros


Complex Regions
===============
.. autosummary::
   :toctree: generated/

   Rectangle
   Domain


Rational Approximation
======================
.. autosummary::
   :toctree: generated/

   AAA
   poles_residues
   zeros
   evaluate
   derivative
